@@ -68,7 +68,7 @@ def build_pipeline_from_repository(repository, tag, profile="", git_creds=None,
     if not brief:
         print("Created Nextflow pipeline %s" % (applet_id))
     else:
-        print(applet_id)
+        print(json.dumps(dict(id=applet_id)))
     return applet_id
 
 
