@@ -20,12 +20,21 @@ Miscellaneous utility classes and functions for the dx-app-wizard command-line t
 
 from __future__ import print_function, unicode_literals, division, absolute_import
 
-import os, shutil, subprocess, re, json
+import os, sys, shutil, subprocess, re, json, platform
 import stat
 
 from ..utils.printing import (BOLD, DNANEXUS_LOGO, ENDC, fill)
 from ..cli import prompt_for_yn
 from ..compat import input, open
+# Import pyreadline3 on Windows with Python >= 3.5
+if platform.system() == 'Windows' and  sys.version_info >= (3, 5):
+    import pyreadline3 as readline
+else:
+    try:
+        # Import gnureadline if installed for macOS
+        import gnureadline as readline
+    except ImportError as e:
+        import readline
 
 from . import python
 from . import bash
@@ -40,10 +49,6 @@ completer_state = {
 }
 
 try:
-    try:
-        import gnureadline as readline
-    except ImportError:
-        import readline
     import rlcompleter
     readline.parse_and_bind("tab: complete")
     readline.set_completer_delims("")
@@ -291,7 +296,6 @@ def create_files_from_templates(template_dir, app_json, language,
             if any(template_filename.endswith(ext) for ext in ('~', '.pyc', '.pyo', '__pycache__')):
                 continue
             use_template_file(os.path.join('test', template_filename))
-
     for template_filename in os.listdir(os.path.join(template_dir, 'src')):
         if template_filename.endswith('~'):
             continue
